@@ -67,7 +67,7 @@ logo()
     "--rule",
     help="Rules directory",
     type=click.Path(exists=True, file_okay=True, dir_okay=True),
-    default=f"{config.HOME_DIR}quark-rules",
+    default=f"{config.DIR_PATH}",
     required=False,
     show_default=True,
 )
@@ -272,7 +272,7 @@ def entry_point(
 
         show_comparison_graph(
             title=f"Malicious Actions Comparison Between {len(apk)} Malwares",
-            lables=selected_label,
+            labels=selected_label,
             malware_confidences=malware_confidences,
             font_size=22,
         )
