@@ -89,6 +89,16 @@ class BaseApkinfo:
         """
         pass
 
+    @property
+    @abstractmethod
+    def receivers(self) -> List[XMLElement]:
+        """
+        Return all receivers from the given APK.
+
+        :return: a list of all receivers
+        """
+        pass
+
     @property
     @abstractmethod
     def android_apis(self) -> Set[MethodObject]:
@@ -124,7 +134,7 @@ class BaseApkinfo:
         class_name: Optional[str] = ".*",
         method_name: Optional[str] = ".*",
         descriptor: Optional[str] = ".*",
-    ) -> MethodObject:
+    ) -> List[MethodObject]:
         """
         Find method from given class_name, method_name and the descriptor.
         default is find all method.
@@ -132,7 +142,7 @@ class BaseApkinfo:
         :param class_name: the class name of the Android API
         :param method_name: the method name of the Android API
         :param descriptor: the descriptor of the Android API
-        :return: a generator of MethodObject
+        :return: a list with MethodObjects
         """
         pass
 
